ActionRegionFlexibleExtent class final

A weighted flexible action-slot extent.

Inheritance

Constructors

ActionRegionFlexibleExtent({int flex = 1, ActionRegionFlexFit fit = ActionRegionFlexFit.tight})
Creates a validated flexible extent.
factory

Properties

fit → ActionRegionFlexFit
Whether the slot must consume its complete share.
final
flex → int
The positive remainder-allocation weight.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited