ActionRegionLayoutReservation class final

A structural width reservation made before Core resolution.

Constructors

ActionRegionLayoutReservation({double fixedExtent = 0})
Creates a validated reservation.
factory

Properties

fixedExtent → double
The fixed width subtracted from placement capacity.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited