ActionRegionSlotLayoutEntry class final

A package-owned slot entry in a layout plan.

Inheritance

Constructors

ActionRegionSlotLayoutEntry(ActionRegionLayoutSlotId id, {ActionRegionExtent extent = const ActionRegionExtent.fixed()})
Creates a slot entry.
const

Properties

extent ActionRegionExtent
The slot's fixed or flexible allocation behavior.
final
hashCode int
The hash code for this object.
no setterinherited
id ActionRegionLayoutSlotId
The slot placed by this entry.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited