AutomaticPlacementPreference class final

Automatic-placement preferences used when primary space is limited.

Constructors

AutomaticPlacementPreference({PrimaryRetentionPriority retentionPriority = PrimaryRetentionPriority.normal, bool allowsHiding = false})
Creates automatic-placement preferences.

Properties

allowsHiding → bool
Whether the action may be hidden instead of exposed through overflow.
final
hashCode → int
The hash code for this object.
no setteroverride
retentionPriority → PrimaryRetentionPriority
Higher values are retained in primary before lower values.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override