MaterialActionIconBuilder<T extends Object> typedef

MaterialActionIconBuilder<T extends Object> = Widget? Function(BuildContext context, AdaptiveAction<T> action)

Builds the Material icon associated with an adaptive action.

Return null when the action has no Material icon. The renderer then uses its label-only primary layout option.

Implementation

typedef MaterialActionIconBuilder<T extends Object> =
    Widget? Function(BuildContext context, AdaptiveAction<T> action);