MaterialActionPresentation enum

A forced primary-button presentation for MaterialAdaptiveActions.

This only selects between Material-owned layout options. It does not change whether an action is placed in primary, overflow, or hidden.

Inheritance
Available extensions

Values

extended → const MaterialActionPresentation

Shows the action label and, when available, its icon.

iconOnly → const MaterialActionPresentation

Shows only the action icon.

An action without an icon falls back to extended.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MaterialActionPresentation>
A constant List of the values in this enum, in order of their declaration.