MaterialAdaptiveActions<T extends Object>.moreAction constructor

const MaterialAdaptiveActions<T extends Object>.moreAction({
  1. Key? key,
  2. required ActionCollection<T> actions,
  3. required ValueChanged<T> onInvoke,
  4. required double primaryCapacity,
  5. Iterable<ActionId> primaryOrderOverride = const [],
  6. Iterable<ActionId> overflowOrderOverride = const [],
  7. ActionLayoutResolver resolver = const ActionLayoutResolver(),
  8. int? maxPrimaryActions,
  9. MaterialActionIconBuilder<T>? iconBuilder,
  10. MaterialActionButtonBuilder<T>? actionButtonBuilder,
  11. MaterialOverflowButtonBuilder? overflowButtonBuilder,
  12. MaterialActionPresentationCallback<T>? presentationForAction,
  13. MaterialActionPresentation? presentationOverride,
  14. MaterialAdaptiveActionsStyle style = const MaterialAdaptiveActionsStyle(),
  15. Widget overflowIcon = const Icon(Icons.more_vert),
  16. String overflowTooltip = 'More actions',
  17. bool menuAnimationEnabled = true,
  18. Duration fadeDuration = const Duration(milliseconds: 200),
  19. Duration resizeDuration = const Duration(milliseconds: 200),
  20. Curve switchInCurve = Curves.easeOut,
  21. Curve switchOutCurve = Curves.easeIn,
})

Creates a Material action region with the conventional More icon.

overflowTooltip defaults to "More actions" and can be replaced with a localized description by the host.

Implementation

const MaterialAdaptiveActions.moreAction({
  super.key,
  required this.actions,
  required this.onInvoke,
  required this.primaryCapacity,
  this.primaryOrderOverride = const [],
  this.overflowOrderOverride = const [],
  this.resolver = const ActionLayoutResolver(),
  this.maxPrimaryActions,
  this.iconBuilder,
  this.actionButtonBuilder,
  this.overflowButtonBuilder,
  this.presentationForAction,
  this.presentationOverride,
  this.style = const MaterialAdaptiveActionsStyle(),
  this.overflowIcon = const Icon(Icons.more_vert),
  this.overflowTooltip = 'More actions',
  this.menuAnimationEnabled = true,
  this.fadeDuration = const Duration(milliseconds: 200),
  this.resizeDuration = const Duration(milliseconds: 200),
  this.switchInCurve = Curves.easeOut,
  this.switchOutCurve = Curves.easeIn,
}) : assert(primaryCapacity >= 0 && primaryCapacity < double.infinity);