actionButtonBuilder property
Overrides leaf actions, primary menu triggers, and composite invoke buttons while preserving the renderer-owned slot constraints.
Implementation
final MaterialActionButtonBuilder<T>? actionButtonBuilder;
Overrides leaf actions, primary menu triggers, and composite invoke buttons while preserving the renderer-owned slot constraints.
final MaterialActionButtonBuilder<T>? actionButtonBuilder;