maxPrimaryActions property
The optional maximum number of root actions shown in primary.
maxPrimaryActions: 3 [Save] [Search] [Share]
maxPrimaryActions: 2 [Save] [Search] [overflow]
Implementation
final int? maxPrimaryActions;
The optional maximum number of root actions shown in primary.
maxPrimaryActions: 3 [Save] [Search] [Share]
maxPrimaryActions: 2 [Save] [Search] [overflow]
final int? maxPrimaryActions;