onInvoke property
Receives the payload of an enabled action after the user invokes it.
user taps [Save] -> onInvoke('save-document') -> host business logic
Implementation
final ValueChanged<T> onInvoke;
Receives the payload of an enabled action after the user invokes it.
user taps [Save] -> onInvoke('save-document') -> host business logic
final ValueChanged<T> onInvoke;