switchInCurve property
The curve used while a boundary action or label appears and expands.
switchInCurve: easeOut new layout: . .. ... [S]
Implementation
final Curve switchInCurve;
The curve used while a boundary action or label appears and expands.
switchInCurve: easeOut new layout: . .. ... [S]
final Curve switchInCurve;