switchOutCurve property
The curve used while a boundary action or label disappears and contracts.
switchOutCurve: easeIn old layout: [Save] ... .. .
Implementation
final Curve switchOutCurve;
The curve used while a boundary action or label disappears and contracts.
switchOutCurve: easeIn old layout: [Save] ... .. .
final Curve switchOutCurve;