height property

double height
final

The preferred action region and button height.

Parent constraints take precedence. A tight 20-pixel-high parent, for example, makes the complete action region and its controls 20 pixels high without requiring a second height value on this widget.

height: 48    [  Save  ]
height: 64    [        ]
              [  Save  ]
              [        ]

Implementation

final double height;