iconLabelSpacing property
The spacing between an icon and label in an extended button.
iconLabelSpacing: 4 [S Save]
iconLabelSpacing: 12 [S Save]
Implementation
final double iconLabelSpacing;
The spacing between an icon and label in an extended button.
iconLabelSpacing: 4 [S Save]
iconLabelSpacing: 12 [S Save]
final double iconLabelSpacing;