ActionLabelLayout class final
Constrains one primary action label without changing its placement policy.
Constructors
- ActionLabelLayout({double? maxWidth, TextOverflow overflow = TextOverflow.ellipsis})
-
Creates a single-line label layout.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxWidth → double?
-
The optional finite maximum label width, or
nullfor no limit.final - overflow → TextOverflow
-
How text exceeding maxWidth is painted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited