ActionPlacement enum
The layout region policy for an adaptive action.
The diagrams use A for one root action and show its possible resolved
region. The renderer decides the actual Widget appearance.
Values
- pinned → const ActionPlacement
-
The action must remain in the primary region.
Capacity constraints may produce a diagnostic, but never move the action.
primary: [A] overflow: hidden: - automatic → const ActionPlacement
-
The resolver may place the action based on its automatic preference.
enough space limited space primary: [A] primary: overflow: overflow: [A] If hiding is allowed, limited space may use hidden [A] instead. - overflowOnly → const ActionPlacement
-
The action must remain in the overflow region.
primary: overflow: [A] hidden: -
The action must not be exposed to the user.
primary: overflow: hidden: [A]
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ActionPlacement> - A constant List of the values in this enum, in order of their declaration.