ActionRegionLayoutSlot class final
A read-only description of one resolved package-owned slot.
Constructors
- ActionRegionLayoutSlot({required ActionRegionLayoutSlotId id, required double minimumExtent})
-
Creates a slot description.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → ActionRegionLayoutSlotId
-
The stable slot identity used by layout plans.
final
- minimumExtent → double
-
The finite, non-negative width required by placement resolution.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited