resizeDuration property
The duration of boundary width expansion and contraction.
Use Duration.zero to remove width interpolation. During a fade-only removal, the old boundary is retained until the fade completes and then snaps to its final width so the outgoing action remains visible.
resizeDuration: 200ms [Save] --shrink--> [S]
resizeDuration: zero [Save] ----------> [S]
Implementation
final Duration resizeDuration;